# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.service_client import SDKClient
from msrest import Configuration, Serializer, Deserializer
from .version import VERSION
from msrest.pipeline import ClientRawResponse
from msrest.exceptions import HttpOperationError
from . import models


class EnigmaVaultAPIConfiguration(Configuration):
    """Configuration for EnigmaVaultAPI
    Note that all parameters used to create this instance are saved as instance
    attributes.

    :param credentials: Subscription credentials which uniquely identify
     client subscription.
    :type credentials: None
    :param str base_url: Service URL
    """

    def __init__(
            self, credentials, base_url=None):

        if credentials is None:
            raise ValueError("Parameter 'credentials' must not be None.")
        if not base_url:
            base_url = 'http://localhost'

        super(EnigmaVaultAPIConfiguration, self).__init__(base_url)

        self.add_user_agent('enigmavaultapi/{}'.format(VERSION))

        self.credentials = credentials


class EnigmaVaultAPI(SDKClient):
    """## Welcome to Enigma Vault's API Documentation
    Enigma Vault encrypts and tokenizes data of all shapes and sizes. Enigma Vault provides the following services:
    - **Card Vault**: encrypts and tokenizes card data. One way in and no way out except through our proxy services.
    - **Data Vault**: encrypts and tokenizes data. Encrypted data can be easily searched and retrieved.
    - **File Vault**: encrypts and stores files up to 5 GB in size.
    To get started, head on over to our [AWS Marketplace page](https://aws.amazon.com/marketplace/seller-profile?id=c77b8db1-5511-48b7-8ce5-9a8d4a1a8018) and select one of our offerings. Once you have credentials, feel free to use the [PostMan app](https://www.postman.com/downloads/)
    or our [Swagger UI](https://api.enigmavault.io/index.html).
    Enigma Vault utilizes AWS Lambda for performance and security reasons. Are you using Lambda as well? You can integrate using your favorite runtime http client or you can also use one of the SDKs below.
    ## Version 1.5 Notes
    ### 02/06/2022
    - Card Vault: you can now generate Luhn passable tokens that preserve the first six and last four of the card number. Because the tokens look like card numbers, the token has been moved to the header.
    ## SDKs
    - [C#](https://www.enigmavault.io/sdks/1.5/enigma-vault-csharp-sdk-1.5.zip)
    - [Java](https://www.enigmavault.io/sdks/1.5/enigma-vault-java-sdk-1.5.zip)
    - [Python](https://www.enigmavault.io/sdks/1.5/enigma-vault-python-sdk-1.5.zip)
    - [Node.js](https://www.enigmavault.io/sdks/1.5/enigma-vault-nodejs-sdk-1.5.zip)
    - [Go](https://www.enigmavault.io/sdks/1.5/enigma-vault-go-sdk-1.5.zip)

    :ivar config: Configuration for client.
    :vartype config: EnigmaVaultAPIConfiguration

    :param credentials: Subscription credentials which uniquely identify
     client subscription.
    :type credentials: None
    :param str base_url: Service URL
    """

    def __init__(
            self, credentials, base_url=None):

        self.config = EnigmaVaultAPIConfiguration(credentials, base_url)
        super(EnigmaVaultAPI, self).__init__(self.config.credentials, self.config)

        client_models = {k: v for k, v in models.__dict__.items() if isinstance(v, type)}
        self.api_version = '1.5'
        self._serialize = Serializer(client_models)
        self._deserialize = Deserializer(client_models)


    def store_card(
            self, body, x_api_version="1.5", preserve_format=None, custom_headers=None, raw=False, **operation_config):
        """Store a card.

        When a card is stored in the vault, the original card information is
        not retrievable by the client without the cardvault_raw scope (contact
        support). The CVV's ttl is set to the same ttl as the card unless the
        card is stored permanently. If the card is stored permanently, the
        CVV's ttl is set to 30 minutes. The CVV is purged after its first use
        or after its ttl expires, whichever comes first. After the card's ttl,
        the card is deleted. To make the card permanent, leave out the ttl
        property. The full card number can be used through the proxy endpoint.
        You can get the first six, the last four, full name, and expiration
        from /cardvault/cards (GET).

        :param body: Card information.
        :type body: ~swagger.models.CardModel
        :param x_api_version: The requested API version
        :type x_api_version: str
        :param preserve_format: If true, a Luhn passable token is returned
         consisting of the original first six and last four.
        :type preserve_format: bool
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.store_card.metadata['url']

        # Construct parameters
        query_parameters = {}
        if preserve_format is not None:
            query_parameters['preserveFormat'] = self._serialize.query("preserve_format", preserve_format, 'bool')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct body
        body_content = self._serialize.body(body, 'CardModel')

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 403, 404, 413, 415, 500]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('CardTokenModel', response)
        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    store_card.metadata = {'url': '/cardvault/cards'}

    def retrieve_card(
            self, card_token, x_api_version="1.5", ephemeral_key=None, custom_headers=None, raw=False, **operation_config):
        """Get a card.

        Provides card data. The first six and the last four are included in the
        response. The ttl values represent the time remaining in seconds until
        that item is purged. the original card information is not retreivable
        by the client without the cardvault_raw scope (contact support). If you
        have the proper scope, use the cardvault/raw/cards endpoint.

        :param card_token: Card token.
        :type card_token: str
        :param x_api_version: The requested API version
        :type x_api_version: str
        :param ephemeral_key: Expiring key for temporary access.
        :type ephemeral_key: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.retrieve_card.metadata['url']

        # Construct parameters
        query_parameters = {}
        if ephemeral_key is not None:
            query_parameters['ephemeralKey'] = self._serialize.query("ephemeral_key", ephemeral_key, 'str')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['cardToken'] = self._serialize.header("card_token", card_token, 'str', max_length=72, min_length=13)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 403, 404, 413, 415, 500]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('CardReadModel', response)
        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    retrieve_card.metadata = {'url': '/cardvault/cards'}

    def delete_card(
            self, card_token, x_api_version="1.5", custom_headers=None, raw=False, **operation_config):
        """Delete a card.

        Returns an empty 204 response on success.

        :param card_token: Card token.
        :type card_token: str
        :param x_api_version: The requested API version
        :type x_api_version: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.delete_card.metadata['url']

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['cardToken'] = self._serialize.header("card_token", card_token, 'str', max_length=72, min_length=13)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct and send request
        request = self._client.delete(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [204, 400, 401, 403, 404, 413, 415, 500]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 204:
            deserialized = self._deserialize('object', response)
        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    delete_card.metadata = {'url': '/cardvault/cards'}

    def retrieve_raw_card(
            self, card_token, x_api_version="1.5", ephemeral_key=None, custom_headers=None, raw=False, **operation_config):
        """Get a card. Scope cardvault_raw only.

        Special endpoint to retreive raw card data. It can only be used with
        the cardvault_raw scope.

        :param card_token: Card token.
        :type card_token: str
        :param x_api_version: The requested API version
        :type x_api_version: str
        :param ephemeral_key: Expiring key for temporary access.
        :type ephemeral_key: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.retrieve_raw_card.metadata['url']

        # Construct parameters
        query_parameters = {}
        if ephemeral_key is not None:
            query_parameters['ephemeralKey'] = self._serialize.query("ephemeral_key", ephemeral_key, 'str')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['cardToken'] = self._serialize.header("card_token", card_token, 'str', max_length=72, min_length=13)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 403, 404, 413, 415, 500]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('CardModel', response)
        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    retrieve_raw_card.metadata = {'url': '/cardvault/raw/cards'}

    def get_card_ephemeral_key(
            self, card_token, destination_client_id, x_api_version="1.5", ttl=None, custom_headers=None, raw=False, **operation_config):
        """Get an ephemeral key for a specific card token and client.

        The ephemeralKey is a one time use expiring key that allows an external
        client to use a card token. The destinationClientId is a valid Enigma
        Vault clientId of the destination app. The time to live (ttl) is in
        seconds.

        :param card_token: Reference to the vaulted card.
        :type card_token: str
        :param destination_client_id: Enigma Vault client granted use of the
         ephemeralKey.
        :type destination_client_id: str
        :param x_api_version: The requested API version
        :type x_api_version: str
        :param ttl: Time to live in seconds, max of 1800 seconds. This is only
         applicable when
         the card has a ttl of 0 (permanent). Otherwise the ephemeralKey ttl is
         set to the card ttl.
        :type ttl: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_card_ephemeral_key.metadata['url']

        # Construct parameters
        query_parameters = {}
        query_parameters['destinationClientId'] = self._serialize.query("destination_client_id", destination_client_id, 'str')
        if ttl is not None:
            query_parameters['ttl'] = self._serialize.query("ttl", ttl, 'int', maximum=1800, minimum=60)

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['cardToken'] = self._serialize.header("card_token", card_token, 'str', max_length=72, min_length=13)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 403, 404, 413, 415, 500]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('EphemeralKeyModel', response)
        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_card_ephemeral_key.metadata = {'url': '/cardvault/cards/ephemeralkeys'}

    def get_ttl(
            self, card_token, x_api_version="1.5", ephemeral_key=None, custom_headers=None, raw=False, **operation_config):
        """Get the current ttl of a card.

        The card's time to live in seconds. Once expired the card is deleted
        from the vault. If -1, the card lives forever until manually deleted.

        :param card_token: Card token.
        :type card_token: str
        :param x_api_version: The requested API version
        :type x_api_version: str
        :param ephemeral_key: Expiring key for temporary access.
        :type ephemeral_key: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_ttl.metadata['url']

        # Construct parameters
        query_parameters = {}
        if ephemeral_key is not None:
            query_parameters['ephemeralKey'] = self._serialize.query("ephemeral_key", ephemeral_key, 'str')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['cardToken'] = self._serialize.header("card_token", card_token, 'str', max_length=72, min_length=13)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 403, 404, 413, 415, 500]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('CardTtlReadModel', response)
        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_ttl.metadata = {'url': '/cardvault/cards/ttl'}

    def update_card_ttl(
            self, body, card_token, x_api_version="1.5", custom_headers=None, raw=False, **operation_config):
        """Update the card ttl.

        Adjusts the time (seconds) until deletion. Additional time cannot be
        added to the CVV's ttl.

        :param body: New card ttl value.
        :type body: ~swagger.models.CardTtlModel
        :param card_token: Card token.
        :type card_token: str
        :param x_api_version: The requested API version
        :type x_api_version: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.update_card_ttl.metadata['url']

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['cardToken'] = self._serialize.header("card_token", card_token, 'str', max_length=72, min_length=13)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct body
        body_content = self._serialize.body(body, 'CardTtlModel')

        # Construct and send request
        request = self._client.put(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [204, 400, 401, 403, 404, 413, 415, 500]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 204:
            deserialized = self._deserialize('object', response)
        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    update_card_ttl.metadata = {'url': '/cardvault/cards/ttl'}

    def card_proxy(
            self, body, card_token, x_api_version="1.5", ephemeral_key=None, custom_headers=None, raw=False, **operation_config):
        """Send detokenized card data and transaction info to a payment gateway.

        This endpoint allows you to use a stored card without touching the card
        data. Build out the request meant for the upstream url and then use the
        following placeholders to have the endpoint populate them with card
        data: ${ccn}, ${cvv}, ${fullName}, ${lastName}, ${firstName},
        ${cardType}, ${mm}, ${yy}, and ${yyyy}. Supports GET/PUT/POST/DELETE.

        :param body: Token and gateway information.
        :type body: ~swagger.models.CardProxyModel
        :param card_token: Card token.
        :type card_token: str
        :param x_api_version: The requested API version
        :type x_api_version: str
        :param ephemeral_key: Expiring key for temporary access.
        :type ephemeral_key: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.card_proxy.metadata['url']

        # Construct parameters
        query_parameters = {}
        if ephemeral_key is not None:
            query_parameters['ephemeralKey'] = self._serialize.query("ephemeral_key", ephemeral_key, 'str')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['cardToken'] = self._serialize.header("card_token", card_token, 'str', max_length=72, min_length=13)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct body
        body_content = self._serialize.body(body, 'CardProxyModel')

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 403, 404, 413, 415, 500, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('GatewayResponseModel', response)
        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)
        if response.status_code == 503:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    card_proxy.metadata = {'url': '/cardvault/proxy'}

    def get_card_process_form(
            self, body, callback_url, show_timer, show_card, ttl, x_api_version="1.5", preserve_format=None, card_types=None, page_header=None, submit_button_text="Pay Now", language="en", submit_button_color="#0078e7", cancel_button_color="#f08080", page_color="#ffffff", submit_button_text_color="#ffffff", cancel_button_text_color="#000000", page_text_color="#000000", cart_table_border_color="#e0e0e0", cart_table_alternate_row_color="#f2f2f2", custom_headers=None, raw=False, **operation_config):
        """Get a url to the card processing UI.

        The card processing UI allows your customers to enter their card data
        and process upstream with the payment gateway without your app touching
        it. Build out the request meant for the upstream url and then use the
        following placeholders to have the endpoint populate them with card
        data: ${total}, ${ccn}, ${cvv}, ${fullName}, ${lastName}, ${firstName},
        ${cardType}, ${mm}, ${yy}, and ${yyyy}. Supports GET/PUT/POST/DELETE.
        The customer is redirected back to your app (callback url) via POST
        with the parameter eVsessionId. You can then use
        /cardvault/process/sessions/ to determine the adjudication. The session
        information is available for 72 hours. If the customer choses to save
        their card, it will be available through the sessions endpoint. If the
        customer chooses to cancel or if the form timeouts, evException will
        have a value within the POST callback. For cancels, evException's value
        will be 'cancel'. For timeouts, the evException's value will be
        'timeout'. There are multiple ways to integrate the card process form.
        You can use it within a popup, redirect or simple iframe.

        :param body: Gateway and cart information.
        :type body: ~swagger.models.CardProcessModel
        :param callback_url: URL the user is redirected to after storing the
         card.
        :type callback_url: str
        :param show_timer: Show or hide the timer.
        :type show_timer: bool
        :param show_card: Show or hide the card visual.
        :type show_card: bool
        :param ttl: Form session time to live in seconds. After it expires,
         the form can no
         longer be used.
        :type ttl: int
        :param x_api_version: The requested API version
        :type x_api_version: str
        :param preserve_format: If true, a Luhn passable token is returned
         consisting of the original first six and last four.
        :type preserve_format: bool
        :param card_types: Card types, comma delimited. Omit for any card.
         (amex, diners_club_carte_blanche, diners_club_international,
         jcb, laser, visa_electron, visa, mastercard, discover, dankort,
         maestro, uatp, mir).
        :type card_types: str
        :param page_header: Configurable page header.
        :type page_header: str
        :param submit_button_text: Text of the submit button.
        :type submit_button_text: str
        :param language: The language to use on the form. Currently en
         (English), es (Spanish),
         fr (French), and zh-Hans (Chinese simplified) are available.
        :type language: str
        :param submit_button_color: The hex color of the submit button.
        :type submit_button_color: str
        :param cancel_button_color: The hex color of the cancel button.
        :type cancel_button_color: str
        :param page_color: The hex color of the page background.
        :type page_color: str
        :param submit_button_text_color: The hex color of the submit button
         text.
        :type submit_button_text_color: str
        :param cancel_button_text_color: The hex color of the cancel button
         text.
        :type cancel_button_text_color: str
        :param page_text_color: The hex color of the page text.
        :type page_text_color: str
        :param cart_table_border_color: The hex color of the cart table header
         and border.
        :type cart_table_border_color: str
        :param cart_table_alternate_row_color: The hex color of the cart
         table's alternating rows.
        :type cart_table_alternate_row_color: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_card_process_form.metadata['url']

        # Construct parameters
        query_parameters = {}
        query_parameters['callbackUrl'] = self._serialize.query("callback_url", callback_url, 'str')
        query_parameters['showTimer'] = self._serialize.query("show_timer", show_timer, 'bool')
        query_parameters['showCard'] = self._serialize.query("show_card", show_card, 'bool')
        query_parameters['ttl'] = self._serialize.query("ttl", ttl, 'int', maximum=1800, minimum=60)
        if preserve_format is not None:
            query_parameters['preserveFormat'] = self._serialize.query("preserve_format", preserve_format, 'bool')
        if card_types is not None:
            query_parameters['cardTypes'] = self._serialize.query("card_types", card_types, 'str')
        if page_header is not None:
            query_parameters['pageHeader'] = self._serialize.query("page_header", page_header, 'str', max_length=35, min_length=3)
        if submit_button_text is not None:
            query_parameters['submitButtonText'] = self._serialize.query("submit_button_text", submit_button_text, 'str', max_length=20, min_length=0)
        if language is not None:
            query_parameters['language'] = self._serialize.query("language", language, 'str', pattern=r'^en|es|fr|zh-Hans$')
        if submit_button_color is not None:
            query_parameters['submitButtonColor'] = self._serialize.query("submit_button_color", submit_button_color, 'str', pattern=r'^#(?:[0-9a-fA-F]{3}){1,2}$')
        if cancel_button_color is not None:
            query_parameters['cancelButtonColor'] = self._serialize.query("cancel_button_color", cancel_button_color, 'str', pattern=r'^#(?:[0-9a-fA-F]{3}){1,2}$')
        if page_color is not None:
            query_parameters['pageColor'] = self._serialize.query("page_color", page_color, 'str', pattern=r'^#(?:[0-9a-fA-F]{3}){1,2}$')
        if submit_button_text_color is not None:
            query_parameters['submitButtonTextColor'] = self._serialize.query("submit_button_text_color", submit_button_text_color, 'str', pattern=r'^#(?:[0-9a-fA-F]{3}){1,2}$')
        if cancel_button_text_color is not None:
            query_parameters['cancelButtonTextColor'] = self._serialize.query("cancel_button_text_color", cancel_button_text_color, 'str', pattern=r'^#(?:[0-9a-fA-F]{3}){1,2}$')
        if page_text_color is not None:
            query_parameters['pageTextColor'] = self._serialize.query("page_text_color", page_text_color, 'str', pattern=r'^#(?:[0-9a-fA-F]{3}){1,2}$')
        if cart_table_border_color is not None:
            query_parameters['cartTableBorderColor'] = self._serialize.query("cart_table_border_color", cart_table_border_color, 'str', pattern=r'^#(?:[0-9a-fA-F]{3}){1,2}$')
        if cart_table_alternate_row_color is not None:
            query_parameters['cartTableAlternateRowColor'] = self._serialize.query("cart_table_alternate_row_color", cart_table_alternate_row_color, 'str', pattern=r'^#(?:[0-9a-fA-F]{3}){1,2}$')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct body
        body_content = self._serialize.body(body, 'CardProcessModel')

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 403, 404, 413, 415, 500]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('CardFormUrlModel', response)
        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_card_process_form.metadata = {'url': '/cardvault/process/forms'}

    def get_card_process_session(
            self, id, x_api_version="1.5", custom_headers=None, raw=False, **operation_config):
        """Get card process session information.

        Obtain the results from the gateway and retrieve the card token if the
        customer decided to save it.

        :param id: Session ID
        :type id: str
        :param x_api_version: The requested API version
        :type x_api_version: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_card_process_session.metadata['url']
        path_format_arguments = {
            'id': self._serialize.url("id", id, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 403, 404, 413, 415, 500]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('CardGatewayCartResponseModel', response)
        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_card_process_session.metadata = {'url': '/cardvault/process/sessions/{id}'}

    def get_card_store_form(
            self, show_timer, show_card, wallet_save, embed_form_for_control, ttl, x_api_version="1.5", card_ttl=None, preserve_format=None, card_types=None, callback_url=None, parent_url=None, page_header=None, language="en", submit_button_text="Save", submit_button_color="#0078e7", cancel_button_color="#f08080", page_color="#ffffff", submit_button_text_color="#ffffff", cancel_button_text_color="#000000", page_text_color="#000000", custom_headers=None, raw=False, **operation_config):
        """Get a url to the card store UI.

        The card store form allows your app to store and later use customer
        card data without touching it. After the cardTtl expires, the card is
        deleted. If the user decides to save the card, the card is stored
        permanently. If you're seeking to permanently store the card outside of
        a transaction (wallet style), set walletSave to true. If you set
        walletSave to true, the buttonText and cardTtl are overriden. If
        walletSave is true the CVV isn't requested. If you intend to use the
        card in a transaction within 30 minutes, set walletSave to false. On
        callback, your app will receive via POST the card token within the
        parameter eVtoken. If the customer chooses to cancel or if the form
        timeouts, the evException parameter will contain the reason. For
        cancels, evException's value will be 'cancel'. For timeouts,
        evException's value will be 'timeout'. If embedFormForControl is set to
        true, pass 'submit' as a message over to the iframe to submit the form.
        On response, the parent will receive an object that consists of the
        status, the token, and CardModel object. There are multiple ways to
        integrate the card store form. You can use it within a popup, redirect,
        simple iframe, or iframe where the parent page has control to submit
        the form. You can find example code for the advanced iframe integration
        on
        [GitHub](https://github.com/Enigma-Vault/card-vault-integration-examples).

        :param show_timer: Show or hide the timer.
        :type show_timer: bool
        :param show_card: Show or hide the card visual.
        :type show_card: bool
        :param wallet_save: Make true to store the card in your app's wallet.
         This overrides
         the cardTtl and buttonText values. The CVV isn't requested if true.
         If you intend to use the card in a transaction within 30 minutes,
         set walletSave to false.
        :type wallet_save: bool
        :param embed_form_for_control: If true, it removes its buttons and
         any additional padding/spacing, and enables the windows interface for
         2-way comms.
        :type embed_form_for_control: bool
        :param ttl: Form session time to live in seconds. After it expires,
         the form can no
         longer be used.
        :type ttl: int
        :param x_api_version: The requested API version
        :type x_api_version: str
        :param card_ttl: The card's time to live in seconds (60-1800 secs).
         Once expired the card is deleted from the vault. Use the
         /cardvault/cards/ttl
         endpoint to extend it. This field is required if walletSave is false.
        :type card_ttl: int
        :param preserve_format: If true, a Luhn passable token is returned
         consisting of the original first six and last four.
        :type preserve_format: bool
        :param card_types: Card types, comma delimited. Omit for any card.
         (amex, diners_club_carte_blanche, diners_club_international,
         jcb, laser, visa_electron, visa, mastercard, discover, dankort,
         maestro, uatp, mir).
        :type card_types: str
        :param callback_url: URL the user is redirected to after storing the
         card.
        :type callback_url: str
        :param parent_url: The parent page URL. The store form uses it when
         embedFormForControl
         is true to communicate with the parent window.
        :type parent_url: str
        :param page_header: Configurable page header.
        :type page_header: str
        :param language: The language to use on the form. Currently en
         (English), es (Spanish),
         fr (French), and zh-Hans (Chinese simplified) are available.
        :type language: str
        :param submit_button_text: Text of the submit button.
        :type submit_button_text: str
        :param submit_button_color: The hex color of the submit button.
        :type submit_button_color: str
        :param cancel_button_color: The hex color of the cancel button.
        :type cancel_button_color: str
        :param page_color: The hex color of the page background.
        :type page_color: str
        :param submit_button_text_color: The hex color of the submit button
         text.
        :type submit_button_text_color: str
        :param cancel_button_text_color: The hex color of the cancel button
         text.
        :type cancel_button_text_color: str
        :param page_text_color: The hex color of the page text.
        :type page_text_color: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_card_store_form.metadata['url']

        # Construct parameters
        query_parameters = {}
        query_parameters['showTimer'] = self._serialize.query("show_timer", show_timer, 'bool')
        query_parameters['showCard'] = self._serialize.query("show_card", show_card, 'bool')
        query_parameters['walletSave'] = self._serialize.query("wallet_save", wallet_save, 'bool')
        query_parameters['embedFormForControl'] = self._serialize.query("embed_form_for_control", embed_form_for_control, 'bool')
        query_parameters['ttl'] = self._serialize.query("ttl", ttl, 'int', maximum=1800, minimum=60)
        if card_ttl is not None:
            query_parameters['cardTtl'] = self._serialize.query("card_ttl", card_ttl, 'int', maximum=1800, minimum=60)
        if preserve_format is not None:
            query_parameters['preserveFormat'] = self._serialize.query("preserve_format", preserve_format, 'bool')
        if card_types is not None:
            query_parameters['cardTypes'] = self._serialize.query("card_types", card_types, 'str')
        if callback_url is not None:
            query_parameters['callbackUrl'] = self._serialize.query("callback_url", callback_url, 'str')
        if parent_url is not None:
            query_parameters['parentUrl'] = self._serialize.query("parent_url", parent_url, 'str')
        if page_header is not None:
            query_parameters['pageHeader'] = self._serialize.query("page_header", page_header, 'str', max_length=35, min_length=3)
        if language is not None:
            query_parameters['language'] = self._serialize.query("language", language, 'str', pattern=r'^en|es|fr|zh-Hans$')
        if submit_button_text is not None:
            query_parameters['submitButtonText'] = self._serialize.query("submit_button_text", submit_button_text, 'str', max_length=20, min_length=0)
        if submit_button_color is not None:
            query_parameters['submitButtonColor'] = self._serialize.query("submit_button_color", submit_button_color, 'str', pattern=r'^#(?:[0-9a-fA-F]{3}){1,2}$')
        if cancel_button_color is not None:
            query_parameters['cancelButtonColor'] = self._serialize.query("cancel_button_color", cancel_button_color, 'str', pattern=r'^#(?:[0-9a-fA-F]{3}){1,2}$')
        if page_color is not None:
            query_parameters['pageColor'] = self._serialize.query("page_color", page_color, 'str', pattern=r'^#(?:[0-9a-fA-F]{3}){1,2}$')
        if submit_button_text_color is not None:
            query_parameters['submitButtonTextColor'] = self._serialize.query("submit_button_text_color", submit_button_text_color, 'str', pattern=r'^#(?:[0-9a-fA-F]{3}){1,2}$')
        if cancel_button_text_color is not None:
            query_parameters['cancelButtonTextColor'] = self._serialize.query("cancel_button_text_color", cancel_button_text_color, 'str', pattern=r'^#(?:[0-9a-fA-F]{3}){1,2}$')
        if page_text_color is not None:
            query_parameters['pageTextColor'] = self._serialize.query("page_text_color", page_text_color, 'str', pattern=r'^#(?:[0-9a-fA-F]{3}){1,2}$')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 403, 404, 413, 415, 500]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('CardFormUrlModel', response)
        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_card_store_form.metadata = {'url': '/cardvault/store/forms'}

    def get_cvv_store_form(
            self, card_token, show_timer, show_cancel_button, auto_save, embed_form_for_control, x_api_version="1.5", callback_url=None, parent_url=None, page_header=None, language="en", submit_button_text="Submit", submit_button_color="#0078e7", cancel_button_color="#f08080", page_color="#ffffff", submit_button_text_color="#ffffff", cancel_button_text_color="#000000", page_text_color="#000000", custom_headers=None, raw=False, **operation_config):
        """Get a url to the CVV store UI.

        The CVV store form allows your app to temporarily store the CVV until
        authorization. The CVV ttl is set to the card's ttl. If the card has a
        ttl of -1, the CVV ttl will be set to 1800 seconds. If autoSave is
        true, the callback will not trigger so the client app will need to
        verify the cvv ttl for its existence. There are multiple ways to
        integrate the cvv form. You can use it within a popup, redirect, simple
        iframe, (previous 3 can use autosave) or iframe where the parent page
        has control to submit the form. You can find example code for the
        advanced iframe integration on
        [GitHub](https://github.com/Enigma-Vault/card-vault-integration-examples).

        :param card_token: Card token.
        :type card_token: str
        :param show_timer: Show or hide the timer.
        :type show_timer: bool
        :param show_cancel_button: Show or hide the cancel button.
        :type show_cancel_button: bool
        :param auto_save: If true, the buttons and header are removed, and cvv
         will be autosaved after user entry.
         The callback will not trigger so the client app will need to verify
         the cvv ttl for its existence.
        :type auto_save: bool
        :param embed_form_for_control: If true, it removes its buttons and
         any additional padding/spacing, and enables the windows interface for
         2-way comms.
        :type embed_form_for_control: bool
        :param x_api_version: The requested API version
        :type x_api_version: str
        :param callback_url: URL the user is redirected to after storing the
         card.
        :type callback_url: str
        :param parent_url: The parent page URL. The store form uses it when
         embedFormForControl
         is true to communicate with the parent window.
        :type parent_url: str
        :param page_header: Configurable page header.
        :type page_header: str
        :param language: The language to use on the form. Currently en
         (English), es (Spanish),
         fr (French), and zh-Hans (Chinese simplified) are available.
        :type language: str
        :param submit_button_text: Text of the submit button.
        :type submit_button_text: str
        :param submit_button_color: The hex color of the submit button.
        :type submit_button_color: str
        :param cancel_button_color: The hex color of the cancel button.
        :type cancel_button_color: str
        :param page_color: The hex color of the page background.
        :type page_color: str
        :param submit_button_text_color: The hex color of the submit button
         text.
        :type submit_button_text_color: str
        :param cancel_button_text_color: The hex color of the cancel button
         text.
        :type cancel_button_text_color: str
        :param page_text_color: The hex color of the page text.
        :type page_text_color: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_cvv_store_form.metadata['url']

        # Construct parameters
        query_parameters = {}
        query_parameters['showTimer'] = self._serialize.query("show_timer", show_timer, 'bool')
        query_parameters['showCancelButton'] = self._serialize.query("show_cancel_button", show_cancel_button, 'bool')
        query_parameters['autoSave'] = self._serialize.query("auto_save", auto_save, 'bool')
        query_parameters['embedFormForControl'] = self._serialize.query("embed_form_for_control", embed_form_for_control, 'bool')
        if callback_url is not None:
            query_parameters['callbackUrl'] = self._serialize.query("callback_url", callback_url, 'str')
        if parent_url is not None:
            query_parameters['parentUrl'] = self._serialize.query("parent_url", parent_url, 'str')
        if page_header is not None:
            query_parameters['pageHeader'] = self._serialize.query("page_header", page_header, 'str', max_length=35, min_length=3)
        if language is not None:
            query_parameters['language'] = self._serialize.query("language", language, 'str', pattern=r'^en|es|fr|zh-Hans$')
        if submit_button_text is not None:
            query_parameters['submitButtonText'] = self._serialize.query("submit_button_text", submit_button_text, 'str', max_length=20, min_length=0)
        if submit_button_color is not None:
            query_parameters['submitButtonColor'] = self._serialize.query("submit_button_color", submit_button_color, 'str', pattern=r'^#(?:[0-9a-fA-F]{3}){1,2}$')
        if cancel_button_color is not None:
            query_parameters['cancelButtonColor'] = self._serialize.query("cancel_button_color", cancel_button_color, 'str', pattern=r'^#(?:[0-9a-fA-F]{3}){1,2}$')
        if page_color is not None:
            query_parameters['pageColor'] = self._serialize.query("page_color", page_color, 'str', pattern=r'^#(?:[0-9a-fA-F]{3}){1,2}$')
        if submit_button_text_color is not None:
            query_parameters['submitButtonTextColor'] = self._serialize.query("submit_button_text_color", submit_button_text_color, 'str', pattern=r'^#(?:[0-9a-fA-F]{3}){1,2}$')
        if cancel_button_text_color is not None:
            query_parameters['cancelButtonTextColor'] = self._serialize.query("cancel_button_text_color", cancel_button_text_color, 'str', pattern=r'^#(?:[0-9a-fA-F]{3}){1,2}$')
        if page_text_color is not None:
            query_parameters['pageTextColor'] = self._serialize.query("page_text_color", page_text_color, 'str', pattern=r'^#(?:[0-9a-fA-F]{3}){1,2}$')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['cardToken'] = self._serialize.header("card_token", card_token, 'str', max_length=72, min_length=13)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 403, 404, 413, 415, 500]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('CardFormUrlModel', response)
        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_cvv_store_form.metadata = {'url': '/cardvault/store/cvv/forms'}

    def get_cultures(
            self, x_api_version="1.5", culture_code=None, custom_headers=None, raw=False, **operation_config):
        """Get a listing of all supported cultures and currencies.

        :param x_api_version: The requested API version
        :type x_api_version: str
        :param culture_code: ISO 639-1 (language) and ISO 3166-1 (country)
         code.
        :type culture_code: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_cultures.metadata['url']

        # Construct parameters
        query_parameters = {}
        if culture_code is not None:
            query_parameters['cultureCode'] = self._serialize.query("culture_code", culture_code, 'str')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 403, 404, 413, 415, 500]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[CultureModel]', response)
        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_cultures.metadata = {'url': '/cardvault/references/cultures'}

    def store_data_secrets(
            self, body, x_api_version="1.5", custom_headers=None, raw=False, **operation_config):
        """Store a secret.

        Supports up to 5,000 plaintext objects per request. Plaintext strings
        must be less than 1000 characters in length. The customIdentifier
        attribute ties your unencrypted data to the tokens. The
        customIdentifier is not stored within the vault.

        :param body: Your secrets to vault.
        :type body: list[~swagger.models.PlaintextCustomerIdentifierModel]
        :param x_api_version: The requested API version
        :type x_api_version: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.store_data_secrets.metadata['url']

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct body
        body_content = self._serialize.body(body, '[PlaintextCustomerIdentifierModel]')

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 403, 404, 413, 415, 500]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[TokenCustomIdentifierModel]', response)
        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    store_data_secrets.metadata = {'url': '/datavault/secrets'}

    def get_data_secret(
            self, token, x_api_version="1.5", ephemeral_key=None, custom_headers=None, raw=False, **operation_config):
        """Get a secret by token.

        The ephemeralKey is a one time use expiring key that allows an external
        client to obtain the token's secret. To generate one, use the
        datavault/secrets/ephemeralKey endpoint.

        :param token: Reference to the vaulted secret.
        :type token: str
        :param x_api_version: The requested API version
        :type x_api_version: str
        :param ephemeral_key: One time use expiring key.
        :type ephemeral_key: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_data_secret.metadata['url']
        path_format_arguments = {
            'token': self._serialize.url("token", token, 'str', max_length=72, min_length=72)
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}
        if ephemeral_key is not None:
            query_parameters['ephemeralKey'] = self._serialize.query("ephemeral_key", ephemeral_key, 'str')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 403, 404, 413, 415, 500]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('PlaintextModel', response)
        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_data_secret.metadata = {'url': '/datavault/secrets/{token}'}

    def delete_data_secret(
            self, token, x_api_version="1.5", custom_headers=None, raw=False, **operation_config):
        """Delete a secret.

        :param token: Reference to the vaulted secret.
        :type token: str
        :param x_api_version: The requested API version
        :type x_api_version: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.delete_data_secret.metadata['url']
        path_format_arguments = {
            'token': self._serialize.url("token", token, 'str', max_length=72, min_length=72)
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct and send request
        request = self._client.delete(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [204, 400, 401, 403, 404, 413, 415, 500]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 204:
            deserialized = self._deserialize('object', response)
        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    delete_data_secret.metadata = {'url': '/datavault/secrets/{token}'}

    def search_data_secrets(
            self, x_api_version="1.5", body=None, custom_headers=None, raw=False, **operation_config):
        """Search by plaintext.

        Exact matches will only be returned and is case sensitive.

        :param x_api_version: The requested API version
        :type x_api_version: str
        :param body: Text to search within the vault. Exact matches will only
         be returned and is case sensitive.
        :type body: ~swagger.models.PlaintextModel
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.search_data_secrets.metadata['url']

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct body
        if body is not None:
            body_content = self._serialize.body(body, 'PlaintextModel')
        else:
            body_content = None

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 403, 404, 413, 415, 500]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[TokenModel]', response)
        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    search_data_secrets.metadata = {'url': '/datavault/search'}

    def get_data_ephemeral_key(
            self, token, destination_client_id, ttl, x_api_version="1.5", custom_headers=None, raw=False, **operation_config):
        """Get an ephemeral key for a specific token and client.

        The ephemeralKey is a one time use expiring key that allows an external
        client to obtain the token's secret. The destinationClientId is a valid
        Enigma Vault clientId of the destination app. The time to live (ttl) is
        in seconds.

        :param token: Reference to the vaulted secret.
        :type token: str
        :param destination_client_id: Enigma Vault client granted use of the
         ephemeralKey.
        :type destination_client_id: str
        :param ttl: Time to live in seconds, max of 300.
        :type ttl: int
        :param x_api_version: The requested API version
        :type x_api_version: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_data_ephemeral_key.metadata['url']
        path_format_arguments = {
            'token': self._serialize.url("token", token, 'str', max_length=72, min_length=72)
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}
        query_parameters['destinationClientId'] = self._serialize.query("destination_client_id", destination_client_id, 'str')
        query_parameters['ttl'] = self._serialize.query("ttl", ttl, 'int', maximum=300, minimum=1)

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 403, 404, 413, 415, 500]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('EphemeralKeyModel', response)
        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_data_ephemeral_key.metadata = {'url': '/datavault/ephemeralkeys/{token}'}

    def get_upload_url(
            self, content_type, file_extension, x_api_version="1.5", custom_headers=None, raw=False, **operation_config):
        """Get a url to upload a file.

        The url is used to upload (PUT) a file into the vault. The url has an
        exipration of five minutes. The file size cannot exceed 5 gigabytes. A
        websocket url is provided so that the status of the file can be tracked
        in realtime.

        :param content_type: The MIME type associated with the file.
        :type content_type: str
        :param file_extension: The file extension without the leading .
        :type file_extension: str
        :param x_api_version: The requested API version
        :type x_api_version: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_upload_url.metadata['url']

        # Construct parameters
        query_parameters = {}
        query_parameters['contentType'] = self._serialize.query("content_type", content_type, 'str', max_length=255, min_length=3)
        query_parameters['fileExtension'] = self._serialize.query("file_extension", file_extension, 'str', pattern=r'^[0-9a-zA-Z]{1,10}$')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 403, 404, 413, 415, 500]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('UploadUrlModel', response)
        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_upload_url.metadata = {'url': '/filevault/uploadurls'}

    def get_file_status(
            self, file_name, x_api_version="1.5", custom_headers=None, raw=False, **operation_config):
        """Get the status of a file.

        This endpoint has been deprecated because the file status is now
        provided through a websocket API.

        :param file_name: Tokenized file name.
        :type file_name: str
        :param x_api_version: The requested API version
        :type x_api_version: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_file_status.metadata['url']
        path_format_arguments = {
            'fileName': self._serialize.url("file_name", file_name, 'str', pattern=r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\.[0-9a-zA-Z]{1,10}$')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 403, 404, 413, 415, 500]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('FileStatusModel', response)
        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_file_status.metadata = {'url': '/filevault/statuses/{fileName}'}

    def get_download_url(
            self, file_name, a_sync_parameter, x_api_version="1.5", ephemeral_key=None, custom_headers=None, raw=False, **operation_config):
        """Get a url to decrypt and download the file.

        The url is used to download the file out of the vault. The url has an
        exipration of five minutes. When aSync is set to true for large files,
        a websocket API url is returned so that the file status can be
        monitored in real time. When the file is finished decrypting, the
        download url is provided through the websocket connection.

        :param file_name: Tokenized file name.
        :type file_name: str
        :param a_sync_parameter: Set to true to decrypt large files; you'll
         use the websocket API for notifications.
        :type a_sync_parameter: bool
        :param x_api_version: The requested API version
        :type x_api_version: str
        :param ephemeral_key: One time use expiring key.
        :type ephemeral_key: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_download_url.metadata['url']
        path_format_arguments = {
            'fileName': self._serialize.url("file_name", file_name, 'str', pattern=r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\.[0-9a-zA-Z]{1,10}$')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}
        query_parameters['aSync'] = self._serialize.query("a_sync_parameter", a_sync_parameter, 'bool')
        if ephemeral_key is not None:
            query_parameters['ephemeralKey'] = self._serialize.query("ephemeral_key", ephemeral_key, 'str')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 202, 400, 401, 403, 404, 409, 413, 415, 500]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('DownloadUrlModel', response)
        if response.status_code == 202:
            deserialized = self._deserialize('WsUrlModel', response)
        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 409:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_download_url.metadata = {'url': '/filevault/downloadurls/{fileName}'}

    def delete_file(
            self, file_name, x_api_version="1.5", custom_headers=None, raw=False, **operation_config):
        """Delete a file.

        On successful deletion, a 204 response is returned.

        :param file_name: Tokenized file name.
        :type file_name: str
        :param x_api_version: The requested API version
        :type x_api_version: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.delete_file.metadata['url']
        path_format_arguments = {
            'fileName': self._serialize.url("file_name", file_name, 'str', pattern=r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\.[0-9a-zA-Z]{1,10}$')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json; v=1.5'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct and send request
        request = self._client.delete(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [204, 400, 401, 403, 404, 413, 415, 500]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    delete_file.metadata = {'url': '/filevault/files/{fileName}'}

    def get_file_ephemeral_key(
            self, file_name, destination_client_id, ttl, x_api_version="1.5", custom_headers=None, raw=False, **operation_config):
        """Get an ephemeral key for a specific fileName and client.

        The ephemeralKey is a one time use expiring key that allows an external
        client to obtain a download url. The destinationClientId is a valid
        Enigma Vault clientId of the destination app. The time to live (ttl) is
        in seconds.

        :param file_name: Tokenized file name.
        :type file_name: str
        :param destination_client_id: Enigma Vault client granted use of the
         ephemeralKey.
        :type destination_client_id: str
        :param ttl: Time to live in seconds, max of 300.
        :type ttl: int
        :param x_api_version: The requested API version
        :type x_api_version: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_file_ephemeral_key.metadata['url']
        path_format_arguments = {
            'fileName': self._serialize.url("file_name", file_name, 'str', pattern=r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\.[0-9a-zA-Z]{1,10}$')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}
        query_parameters['destinationClientId'] = self._serialize.query("destination_client_id", destination_client_id, 'str')
        query_parameters['ttl'] = self._serialize.query("ttl", ttl, 'int', maximum=300, minimum=1)

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)
        header_parameters['x-api-version'] = self._serialize.header("x_api_version", x_api_version, 'str')

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 403, 404, 413, 415, 500]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('EphemeralKeyModel', response)
        if response.status_code == 400:
            deserialized = self._deserialize('{[str]}', response)
        if response.status_code == 401:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 403:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 404:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 413:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 415:
            deserialized = self._deserialize('ClientErrorModel', response)
        if response.status_code == 500:
            deserialized = self._deserialize('ServerErrorModel', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_file_ephemeral_key.metadata = {'url': '/filevault/ephemeralkeys/{fileName}'}
